<!-- warning: Please don't edit this file. It was automatically generated. -->

# winui3-Microsoft.UI.Xaml.Data

Windows Runtime (WinRT) APIs for for the `winui3-Microsoft.UI.Xaml.Data` namespace.

This package provides the `winui3.microsoft.ui.xaml.data` module.
